==> locomotive_booking_plugin-1.0.0.gem: lib/locomotive/booking/plugin/get_bookings_tag.rb <==
require 'locomotive_plugins'
require 'json'

require_relative 'booking_document'
require_relative 'helper'

module Locomotive
    module Booking
        class GetBookingsTag < ::Liquid::Tag
            ## Extend the String class with is_i? to determine whether the string is a number or not.
            class ::String
                def is_i?
                    ## The regex checks if the String begins with a number, only has numbers in the middle and ends with a number.
                    /\A\d+\Z/.match(self)
                end
            end

            def initialize(tag_name, markup, tokens, context)
                @calendar_week = nil
                @calendar_year = nil

                markup.scan(::Liquid::TagAttributes) do |key, value|
                    ## Apparently you should remove possible quotes from the value.
                    value_minus_quotes = Helper.strip_quotes_from_value(value)

                    ## Dynamically set the instance variable based on the key, but only if it has been defined previously
                    ## and if the values are actually numbers.
                    instance_variable_key = "@#{key}"
                    if instance_variable_defined? instance_variable_key
                        instance_variable_set(instance_variable_key, value_minus_quotes)
                    end
                end
                super
            end

            def render(context)
                ## Resolve the values if it's an expression rather than a
                ## constant.
                year = @calendar_year
                week = @calendar_week

                evaluated_year = context[@calendar_year]
                evaluated_week = context[@calendar_week]

                year = evaluated_year unless evaluated_year.nil? or evaluated_year.empty?
                week = evaluated_week unless evaluated_week.nil? or evaluated_week.empty?

                if year.is_i? and week.is_i?
                    year = year.to_i
                    week = week.to_i
                else
                    return nil.to_json
                end

                if week < 1 or week > 52
                    nil.to_json
                else
                    booking_data = BookingDocument::Availability.without(:_id).where(year: year, week: week).first
                    if booking_data
                        booking_data.as_document.to_json
                    else
                        nil.to_json
                    end
                end
            end

            def render_disabled(context)
                nil.to_json
            end
        end
    end
end

==> locomotive_booking_plugin-1.0.2.gem: lib/locomotive/booking/plugin/get_bookings_tag.rb <==
require 'locomotive_plugins'
require 'json'

require_relative 'booking_document'
require_relative 'helper'

module Locomotive
    module Booking
        class GetBookingsTag < ::Liquid::Tag
            ## Extend the String class with is_i? to determine whether the string is a number or not.
            class ::String
                def is_i?
                    ## The regex checks if the String begins with a number, only has numbers in the middle and ends with a number.
                    /\A\d+\Z/.match(self)
                end
            end

            def initialize(tag_name, markup, tokens, context)
                @calendar_week = nil
                @calendar_year = nil

                markup.scan(::Liquid::TagAttributes) do |key, value|
                    ## Apparently you should remove possible quotes from the value.
                    value_minus_quotes = ::Helper.strip_quotes_from_value(value)

                    ## Dynamically set the instance variable based on the key, but only if it has been defined previously
                    ## and if the values are actually numbers.
                    instance_variable_key = "@#{key}"
                    if instance_variable_defined? instance_variable_key
                        instance_variable_set(instance_variable_key, value_minus_quotes)
                    end
                end
                super
            end

            def render(context)
                ## Resolve the values if it's an expression rather than a
                ## constant.
                year = @calendar_year
                week = @calendar_week

                evaluated_year = context[@calendar_year]
                evaluated_week = context[@calendar_week]

                year = evaluated_year unless evaluated_year.nil? or evaluated_year.empty?
                week = evaluated_week unless evaluated_week.nil? or evaluated_week.empty?

                if year.is_i? and week.is_i?
                    year = year.to_i
                    week = week.to_i
                else
                    return nil.to_json
                end

                if week < 1 or week > 52
                    nil.to_json
                else
                    booking_data = BookingDocument::Availability.without(:_id).where(year: year, week: week).first
                    if booking_data
                        booking_data.as_document.to_json
                    else
                        nil.to_json
                    end
                end
            end

            def render_disabled(context)
                nil.to_json
            end
        end
    end
end
